notedown: Create IPython notebooks from markdown
================================================

Description
-----------

Notedown is a simple tool to create IPython notebooks from markdown.

License
-------

BSD 2-Clause License


Upstream Contact
----------------

Author: Aaron O'Leary Home page: https://github.com/aaren/notedown

